==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ListValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ListValueFluent<A extends ListValueFluent<A>> extends Fluent<A>{
  public A addToValues(Integer index,Value item);
  public A setToValues(Integer index,Value item);
  public A addToValues(io.fabric8.istio.api.internal.protobuf.types.Value... items);
  public A addAllToValues(Collection<Value> items);
  public A removeFromValues(io.fabric8.istio.api.internal.protobuf.types.Value... items);
  public A removeAllFromValues(Collection<Value> items);
  public A removeMatchingFromValues(Predicate<ValueBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildValues instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Value> getValues();
  public List<Value> buildValues();
  public Value buildValue(Integer index);
  public Value buildFirstValue();
  public Value buildLastValue();
  public Value buildMatchingValue(Predicate<ValueBuilder> predicate);
  public Boolean hasMatchingValue(Predicate<ValueBuilder> predicate);
  public A withValues(List<Value> values);
  public A withValues(io.fabric8.istio.api.internal.protobuf.types.Value... values);
  public Boolean hasValues();
  public ListValueFluent.ValuesNested<A> addNewValue();
  public ListValueFluent.ValuesNested<A> addNewValueLike(Value item);
  public ListValueFluent.ValuesNested<A> setNewValueLike(Integer index,Value item);
  public ListValueFluent.ValuesNested<A> editValue(Integer index);
  public ListValueFluent.ValuesNested<A> editFirstValue();
  public ListValueFluent.ValuesNested<A> editLastValue();
  public ListValueFluent.ValuesNested<A> editMatchingValue(Predicate<ValueBuilder> predicate);
  public interface ValuesNested<N> extends Nested<N>,ValueFluent<ListValueFluent.ValuesNested<N>>{
    public N and();
    public N endValue();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ListValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ListValueFluent<A extends ListValueFluent<A>> extends Fluent<A>{
  public A addToValues(int index,Value item);
  public A setToValues(int index,Value item);
  public A addToValues(io.fabric8.istio.api.internal.protobuf.types.Value... items);
  public A addAllToValues(Collection<Value> items);
  public A removeFromValues(io.fabric8.istio.api.internal.protobuf.types.Value... items);
  public A removeAllFromValues(Collection<Value> items);
  public A removeMatchingFromValues(Predicate<ValueBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildValues instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Value> getValues();
  public List<Value> buildValues();
  public Value buildValue(int index);
  public Value buildFirstValue();
  public Value buildLastValue();
  public Value buildMatchingValue(Predicate<ValueBuilder> predicate);
  public Boolean hasMatchingValue(Predicate<ValueBuilder> predicate);
  public A withValues(List<Value> values);
  public A withValues(io.fabric8.istio.api.internal.protobuf.types.Value... values);
  public Boolean hasValues();
  public ListValueFluent.ValuesNested<A> addNewValue();
  public ListValueFluent.ValuesNested<A> addNewValueLike(Value item);
  public ListValueFluent.ValuesNested<A> setNewValueLike(int index,Value item);
  public ListValueFluent.ValuesNested<A> editValue(int index);
  public ListValueFluent.ValuesNested<A> editFirstValue();
  public ListValueFluent.ValuesNested<A> editLastValue();
  public ListValueFluent.ValuesNested<A> editMatchingValue(Predicate<ValueBuilder> predicate);
  public interface ValuesNested<N> extends Nested<N>,ValueFluent<ListValueFluent.ValuesNested<N>>{
    public N and();
    public N endValue();
    
  }
  
}
